# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]


## [0.0.1] - 2019-12-25

### Added

- Initial open source commit.

### Changed

- Added repository boilerplate.

### Removed

- N/A

[unreleased]: https://github.com/zeropointdynamics/zelos/compare/v1.1.0...HEAD
[0.0.1]: https://github.com/zeropointdynamics/zelos/releases/tag/v0.0.1
